==> vim-7.3.645-arm-1.tgz: install/doinst.sh <==
#!/bin/sh
config() {
  NEW="$1"
  OLD="$(dirname $NEW)/$(basename $NEW .new)"
  # If there's no config file by that name, mv it over:
  if [ ! -r $OLD ]; then
    mv $NEW $OLD
  elif [ "$(cat $OLD | md5sum)" = "$(cat $NEW | md5sum)" ]; then # toss the redundant copy
    rm $NEW
  fi
  # Otherwise, we leave the .new copy for the admin to consider...
}
config usr/share/vim/vimrc.new

# If there's no vi link, take over:
if [ ! -r usr/bin/vi ]; then
  ( cd usr/bin ; ln -sf vim vi )
fi
( cd usr/man/fr.ISO8859-1/man1 ; rm -rf view.1.gz )
( cd usr/man/fr.ISO8859-1/man1 ; ln -sf vim.1.gz view.1.gz )
( cd usr/man/fr.ISO8859-1/man1 ; rm -rf rview.1.gz )
( cd usr/man/fr.ISO8859-1/man1 ; ln -sf vim.1.gz rview.1.gz )
( cd usr/man/fr.ISO8859-1/man1 ; rm -rf ex.1.gz )
( cd usr/man/fr.ISO8859-1/man1 ; ln -sf vim.1.gz ex.1.gz )
( cd usr/man/fr.ISO8859-1/man1 ; rm -rf rvim.1.gz )
( cd usr/man/fr.ISO8859-1/man1 ; ln -sf vim.1.gz rvim.1.gz )
( cd usr/man/ru.KOI8-R/man1 ; rm -rf view.1.gz )
( cd usr/man/ru.KOI8-R/man1 ; ln -sf vim.1.gz view.1.gz )
( cd usr/man/ru.KOI8-R/man1 ; rm -rf rview.1.gz )
( cd usr/man/ru.KOI8-R/man1 ; ln -sf vim.1.gz rview.1.gz )
( cd usr/man/ru.KOI8-R/man1 ; rm -rf ex.1.gz )
( cd usr/man/ru.KOI8-R/man1 ; ln -sf vim.1.gz ex.1.gz )
( cd usr/man/ru.KOI8-R/man1 ; rm -rf rvim.1.gz )
( cd usr/man/ru.KOI8-R/man1 ; ln -sf vim.1.gz rvim.1.gz )
( cd usr/man/pl.ISO8859-2/man1 ; rm -rf view.1.gz )
( cd usr/man/pl.ISO8859-2/man1 ; ln -sf vim.1.gz view.1.gz )
( cd usr/man/pl.ISO8859-2/man1 ; rm -rf rview.1.gz )
( cd usr/man/pl.ISO8859-2/man1 ; ln -sf vim.1.gz rview.1.gz )
( cd usr/man/pl.ISO8859-2/man1 ; rm -rf ex.1.gz )
( cd usr/man/pl.ISO8859-2/man1 ; ln -sf vim.1.gz ex.1.gz )
( cd usr/man/pl.ISO8859-2/man1 ; rm -rf rvim.1.gz )
( cd usr/man/pl.ISO8859-2/man1 ; ln -sf vim.1.gz rvim.1.gz )
( cd usr/man/pl/man1 ; rm -rf view.1.gz )
( cd usr/man/pl/man1 ; ln -sf vim.1.gz view.1.gz )
( cd usr/man/pl/man1 ; rm -rf rview.1.gz )
( cd usr/man/pl/man1 ; ln -sf vim.1.gz rview.1.gz )
( cd usr/man/pl/man1 ; rm -rf ex.1.gz )
( cd usr/man/pl/man1 ; ln -sf vim.1.gz ex.1.gz )
( cd usr/man/pl/man1 ; rm -rf rvim.1.gz )
( cd usr/man/pl/man1 ; ln -sf vim.1.gz rvim.1.gz )
( cd usr/man/it/man1 ; rm -rf view.1.gz )
( cd usr/man/it/man1 ; ln -sf vim.1.gz view.1.gz )
( cd usr/man/it/man1 ; rm -rf rview.1.gz )
( cd usr/man/it/man1 ; ln -sf vim.1.gz rview.1.gz )
( cd usr/man/it/man1 ; rm -rf ex.1.gz )
( cd usr/man/it/man1 ; ln -sf vim.1.gz ex.1.gz )
( cd usr/man/it/man1 ; rm -rf rvim.1.gz )
( cd usr/man/it/man1 ; ln -sf vim.1.gz rvim.1.gz )
( cd usr/man/ru.UTF-8/man1 ; rm -rf view.1.gz )
( cd usr/man/ru.UTF-8/man1 ; ln -sf vim.1.gz view.1.gz )
( cd usr/man/ru.UTF-8/man1 ; rm -rf rview.1.gz )
( cd usr/man/ru.UTF-8/man1 ; ln -sf vim.1.gz rview.1.gz )
( cd usr/man/ru.UTF-8/man1 ; rm -rf ex.1.gz )
( cd usr/man/ru.UTF-8/man1 ; ln -sf vim.1.gz ex.1.gz )
( cd usr/man/ru.UTF-8/man1 ; rm -rf rvim.1.gz )
( cd usr/man/ru.UTF-8/man1 ; ln -sf vim.1.gz rvim.1.gz )
( cd usr/man/it.UTF-8/man1 ; rm -rf view.1.gz )
( cd usr/man/it.UTF-8/man1 ; ln -sf vim.1.gz view.1.gz )
( cd usr/man/it.UTF-8/man1 ; rm -rf rview.1.gz )
( cd usr/man/it.UTF-8/man1 ; ln -sf vim.1.gz rview.1.gz )
( cd usr/man/it.UTF-8/man1 ; rm -rf ex.1.gz )
( cd usr/man/it.UTF-8/man1 ; ln -sf vim.1.gz ex.1.gz )
( cd usr/man/it.UTF-8/man1 ; rm -rf rvim.1.gz )
( cd usr/man/it.UTF-8/man1 ; ln -sf vim.1.gz rvim.1.gz )
( cd usr/man/fr/man1 ; rm -rf view.1.gz )
( cd usr/man/fr/man1 ; ln -sf vim.1.gz view.1.gz )
( cd usr/man/fr/man1 ; rm -rf rview.1.gz )
( cd usr/man/fr/man1 ; ln -sf vim.1.gz rview.1.gz )
( cd usr/man/fr/man1 ; rm -rf ex.1.gz )
( cd usr/man/fr/man1 ; ln -sf vim.1.gz ex.1.gz )
( cd usr/man/fr/man1 ; rm -rf rvim.1.gz )
( cd usr/man/fr/man1 ; ln -sf vim.1.gz rvim.1.gz )
( cd usr/man/fr.UTF-8/man1 ; rm -rf view.1.gz )
( cd usr/man/fr.UTF-8/man1 ; ln -sf vim.1.gz view.1.gz )
( cd usr/man/fr.UTF-8/man1 ; rm -rf rview.1.gz )
( cd usr/man/fr.UTF-8/man1 ; ln -sf vim.1.gz rview.1.gz )
( cd usr/man/fr.UTF-8/man1 ; rm -rf ex.1.gz )
( cd usr/man/fr.UTF-8/man1 ; ln -sf vim.1.gz ex.1.gz )
( cd usr/man/fr.UTF-8/man1 ; rm -rf rvim.1.gz )
( cd usr/man/fr.UTF-8/man1 ; ln -sf vim.1.gz rvim.1.gz )
( cd usr/man/man1 ; rm -rf view.1.gz )
( cd usr/man/man1 ; ln -sf vim.1.gz view.1.gz )
( cd usr/man/man1 ; rm -rf rview.1.gz )
( cd usr/man/man1 ; ln -sf vim.1.gz rview.1.gz )
( cd usr/man/man1 ; rm -rf ex.1.gz )
( cd usr/man/man1 ; ln -sf vim.1.gz ex.1.gz )
( cd usr/man/man1 ; rm -rf rvim.1.gz )
( cd usr/man/man1 ; ln -sf vim.1.gz rvim.1.gz )
( cd usr/man/it.ISO8859-1/man1 ; rm -rf view.1.gz )
( cd usr/man/it.ISO8859-1/man1 ; ln -sf vim.1.gz view.1.gz )
( cd usr/man/it.ISO8859-1/man1 ; rm -rf rview.1.gz )
( cd usr/man/it.ISO8859-1/man1 ; ln -sf vim.1.gz rview.1.gz )
( cd usr/man/it.ISO8859-1/man1 ; rm -rf ex.1.gz )
( cd usr/man/it.ISO8859-1/man1 ; ln -sf vim.1.gz ex.1.gz )
( cd usr/man/it.ISO8859-1/man1 ; rm -rf rvim.1.gz )
( cd usr/man/it.ISO8859-1/man1 ; ln -sf vim.1.gz rvim.1.gz )
( cd usr/man/pl.UTF-8/man1 ; rm -rf view.1.gz )
( cd usr/man/pl.UTF-8/man1 ; ln -sf vim.1.gz view.1.gz )
( cd usr/man/pl.UTF-8/man1 ; rm -rf rview.1.gz )
( cd usr/man/pl.UTF-8/man1 ; ln -sf vim.1.gz rview.1.gz )
( cd usr/man/pl.UTF-8/man1 ; rm -rf ex.1.gz )
( cd usr/man/pl.UTF-8/man1 ; ln -sf vim.1.gz ex.1.gz )
( cd usr/man/pl.UTF-8/man1 ; rm -rf rvim.1.gz )
( cd usr/man/pl.UTF-8/man1 ; ln -sf vim.1.gz rvim.1.gz )
( cd usr/bin ; rm -rf eview )
( cd usr/bin ; ln -sf vim eview )
( cd usr/bin ; rm -rf view )
( cd usr/bin ; ln -sf vim view )
( cd usr/bin ; rm -rf rview )
( cd usr/bin ; ln -sf vim rview )
( cd usr/bin ; rm -rf vimdiff )
( cd usr/bin ; ln -sf vim vimdiff )
( cd usr/bin ; rm -rf ex )
( cd usr/bin ; ln -sf vim ex )
( cd usr/bin ; rm -rf evim )
( cd usr/bin ; ln -sf vim evim )
( cd usr/bin ; rm -rf rvim )
( cd usr/bin ; ln -sf vim rvim )
( cd usr/doc/vim-7.3.645 ; rm -rf doc )
( cd usr/doc/vim-7.3.645 ; ln -sf /usr/share/vim/vim72 doc )

==> vim-7.4.050-arm-1.tgz: install/doinst.sh <==
#!/bin/sh
config() {
  NEW="$1"
  OLD="$(dirname $NEW)/$(basename $NEW .new)"
  # If there's no config file by that name, mv it over:
  if [ ! -r $OLD ]; then
    mv $NEW $OLD
  elif [ "$(cat $OLD | md5sum)" = "$(cat $NEW | md5sum)" ]; then # toss the redundant copy
    rm $NEW
  fi
  # Otherwise, we leave the .new copy for the admin to consider...
}
config usr/share/vim/vimrc.new

# If there's no vi link, take over:
if [ ! -r usr/bin/vi ]; then
  ( cd usr/bin ; ln -sf vim vi )
fi
( cd usr/man/fr.UTF-8/man1 ; rm -rf rvim.1.gz )
( cd usr/man/fr.UTF-8/man1 ; ln -sf vim.1.gz rvim.1.gz )
( cd usr/man/fr.UTF-8/man1 ; rm -rf ex.1.gz )
( cd usr/man/fr.UTF-8/man1 ; ln -sf vim.1.gz ex.1.gz )
( cd usr/man/fr.UTF-8/man1 ; rm -rf view.1.gz )
( cd usr/man/fr.UTF-8/man1 ; ln -sf vim.1.gz view.1.gz )
( cd usr/man/fr.UTF-8/man1 ; rm -rf rview.1.gz )
( cd usr/man/fr.UTF-8/man1 ; ln -sf vim.1.gz rview.1.gz )
( cd usr/man/pl.UTF-8/man1 ; rm -rf rvim.1.gz )
( cd usr/man/pl.UTF-8/man1 ; ln -sf vim.1.gz rvim.1.gz )
( cd usr/man/pl.UTF-8/man1 ; rm -rf ex.1.gz )
( cd usr/man/pl.UTF-8/man1 ; ln -sf vim.1.gz ex.1.gz )
( cd usr/man/pl.UTF-8/man1 ; rm -rf view.1.gz )
( cd usr/man/pl.UTF-8/man1 ; ln -sf vim.1.gz view.1.gz )
( cd usr/man/pl.UTF-8/man1 ; rm -rf rview.1.gz )
( cd usr/man/pl.UTF-8/man1 ; ln -sf vim.1.gz rview.1.gz )
( cd usr/man/it/man1 ; rm -rf rvim.1.gz )
( cd usr/man/it/man1 ; ln -sf vim.1.gz rvim.1.gz )
( cd usr/man/it/man1 ; rm -rf ex.1.gz )
( cd usr/man/it/man1 ; ln -sf vim.1.gz ex.1.gz )
( cd usr/man/it/man1 ; rm -rf view.1.gz )
( cd usr/man/it/man1 ; ln -sf vim.1.gz view.1.gz )
( cd usr/man/it/man1 ; rm -rf rview.1.gz )
( cd usr/man/it/man1 ; ln -sf vim.1.gz rview.1.gz )
( cd usr/man/ja/man1 ; rm -rf rvim.1.gz )
( cd usr/man/ja/man1 ; ln -sf vim.1.gz rvim.1.gz )
( cd usr/man/ja/man1 ; rm -rf ex.1.gz )
( cd usr/man/ja/man1 ; ln -sf vim.1.gz ex.1.gz )
( cd usr/man/ja/man1 ; rm -rf view.1.gz )
( cd usr/man/ja/man1 ; ln -sf vim.1.gz view.1.gz )
( cd usr/man/ja/man1 ; rm -rf rview.1.gz )
( cd usr/man/ja/man1 ; ln -sf vim.1.gz rview.1.gz )
( cd usr/man/fr.ISO8859-1/man1 ; rm -rf rvim.1.gz )
( cd usr/man/fr.ISO8859-1/man1 ; ln -sf vim.1.gz rvim.1.gz )
( cd usr/man/fr.ISO8859-1/man1 ; rm -rf ex.1.gz )
( cd usr/man/fr.ISO8859-1/man1 ; ln -sf vim.1.gz ex.1.gz )
( cd usr/man/fr.ISO8859-1/man1 ; rm -rf view.1.gz )
( cd usr/man/fr.ISO8859-1/man1 ; ln -sf vim.1.gz view.1.gz )
( cd usr/man/fr.ISO8859-1/man1 ; rm -rf rview.1.gz )
( cd usr/man/fr.ISO8859-1/man1 ; ln -sf vim.1.gz rview.1.gz )
( cd usr/man/man1 ; rm -rf rvim.1.gz )
( cd usr/man/man1 ; ln -sf vim.1.gz rvim.1.gz )
( cd usr/man/man1 ; rm -rf ex.1.gz )
( cd usr/man/man1 ; ln -sf vim.1.gz ex.1.gz )
( cd usr/man/man1 ; rm -rf view.1.gz )
( cd usr/man/man1 ; ln -sf vim.1.gz view.1.gz )
( cd usr/man/man1 ; rm -rf rview.1.gz )
( cd usr/man/man1 ; ln -sf vim.1.gz rview.1.gz )
( cd usr/man/ru.KOI8-R/man1 ; rm -rf rvim.1.gz )
( cd usr/man/ru.KOI8-R/man1 ; ln -sf vim.1.gz rvim.1.gz )
( cd usr/man/ru.KOI8-R/man1 ; rm -rf ex.1.gz )
( cd usr/man/ru.KOI8-R/man1 ; ln -sf vim.1.gz ex.1.gz )
( cd usr/man/ru.KOI8-R/man1 ; rm -rf view.1.gz )
( cd usr/man/ru.KOI8-R/man1 ; ln -sf vim.1.gz view.1.gz )
( cd usr/man/ru.KOI8-R/man1 ; rm -rf rview.1.gz )
( cd usr/man/ru.KOI8-R/man1 ; ln -sf vim.1.gz rview.1.gz )
( cd usr/man/ru.UTF-8/man1 ; rm -rf rvim.1.gz )
( cd usr/man/ru.UTF-8/man1 ; ln -sf vim.1.gz rvim.1.gz )
( cd usr/man/ru.UTF-8/man1 ; rm -rf ex.1.gz )
( cd usr/man/ru.UTF-8/man1 ; ln -sf vim.1.gz ex.1.gz )
( cd usr/man/ru.UTF-8/man1 ; rm -rf view.1.gz )
( cd usr/man/ru.UTF-8/man1 ; ln -sf vim.1.gz view.1.gz )
( cd usr/man/ru.UTF-8/man1 ; rm -rf rview.1.gz )
( cd usr/man/ru.UTF-8/man1 ; ln -sf vim.1.gz rview.1.gz )
( cd usr/man/fr/man1 ; rm -rf rvim.1.gz )
( cd usr/man/fr/man1 ; ln -sf vim.1.gz rvim.1.gz )
( cd usr/man/fr/man1 ; rm -rf ex.1.gz )
( cd usr/man/fr/man1 ; ln -sf vim.1.gz ex.1.gz )
( cd usr/man/fr/man1 ; rm -rf view.1.gz )
( cd usr/man/fr/man1 ; ln -sf vim.1.gz view.1.gz )
( cd usr/man/fr/man1 ; rm -rf rview.1.gz )
( cd usr/man/fr/man1 ; ln -sf vim.1.gz rview.1.gz )
( cd usr/man/pl/man1 ; rm -rf rvim.1.gz )
( cd usr/man/pl/man1 ; ln -sf vim.1.gz rvim.1.gz )
( cd usr/man/pl/man1 ; rm -rf ex.1.gz )
( cd usr/man/pl/man1 ; ln -sf vim.1.gz ex.1.gz )
( cd usr/man/pl/man1 ; rm -rf view.1.gz )
( cd usr/man/pl/man1 ; ln -sf vim.1.gz view.1.gz )
( cd usr/man/pl/man1 ; rm -rf rview.1.gz )
( cd usr/man/pl/man1 ; ln -sf vim.1.gz rview.1.gz )
( cd usr/man/it.UTF-8/man1 ; rm -rf rvim.1.gz )
( cd usr/man/it.UTF-8/man1 ; ln -sf vim.1.gz rvim.1.gz )
( cd usr/man/it.UTF-8/man1 ; rm -rf ex.1.gz )
( cd usr/man/it.UTF-8/man1 ; ln -sf vim.1.gz ex.1.gz )
( cd usr/man/it.UTF-8/man1 ; rm -rf view.1.gz )
( cd usr/man/it.UTF-8/man1 ; ln -sf vim.1.gz view.1.gz )
( cd usr/man/it.UTF-8/man1 ; rm -rf rview.1.gz )
( cd usr/man/it.UTF-8/man1 ; ln -sf vim.1.gz rview.1.gz )
( cd usr/man/pl.ISO8859-2/man1 ; rm -rf rvim.1.gz )
( cd usr/man/pl.ISO8859-2/man1 ; ln -sf vim.1.gz rvim.1.gz )
( cd usr/man/pl.ISO8859-2/man1 ; rm -rf ex.1.gz )
( cd usr/man/pl.ISO8859-2/man1 ; ln -sf vim.1.gz ex.1.gz )
( cd usr/man/pl.ISO8859-2/man1 ; rm -rf view.1.gz )
( cd usr/man/pl.ISO8859-2/man1 ; ln -sf vim.1.gz view.1.gz )
( cd usr/man/pl.ISO8859-2/man1 ; rm -rf rview.1.gz )
( cd usr/man/pl.ISO8859-2/man1 ; ln -sf vim.1.gz rview.1.gz )
( cd usr/man/it.ISO8859-1/man1 ; rm -rf rvim.1.gz )
( cd usr/man/it.ISO8859-1/man1 ; ln -sf vim.1.gz rvim.1.gz )
( cd usr/man/it.ISO8859-1/man1 ; rm -rf ex.1.gz )
( cd usr/man/it.ISO8859-1/man1 ; ln -sf vim.1.gz ex.1.gz )
( cd usr/man/it.ISO8859-1/man1 ; rm -rf view.1.gz )
( cd usr/man/it.ISO8859-1/man1 ; ln -sf vim.1.gz view.1.gz )
( cd usr/man/it.ISO8859-1/man1 ; rm -rf rview.1.gz )
( cd usr/man/it.ISO8859-1/man1 ; ln -sf vim.1.gz rview.1.gz )
( cd usr/doc/vim-7.4.050 ; rm -rf doc )
( cd usr/doc/vim-7.4.050 ; ln -sf /usr/share/vim/vim74 doc )
( cd usr/bin ; rm -rf rvim )
( cd usr/bin ; ln -sf vim rvim )
( cd usr/bin ; rm -rf evim )
( cd usr/bin ; ln -sf vim evim )
( cd usr/bin ; rm -rf ex )
( cd usr/bin ; ln -sf vim ex )
( cd usr/bin ; rm -rf view )
( cd usr/bin ; ln -sf vim view )
( cd usr/bin ; rm -rf rview )
( cd usr/bin ; ln -sf vim rview )
( cd usr/bin ; rm -rf eview )
( cd usr/bin ; ln -sf vim eview )
( cd usr/bin ; rm -rf vimdiff )
( cd usr/bin ; ln -sf vim vimdiff )
